==> R14.1.0-core.tar: tdemultimedia-trinity-14.1.0/tdemid/main.cpp <==
/**************************************************************************

    main.cpp  - The main function for KMid
    Copyright (C) 1997,98  Antonio Larrosa Jimenez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Send comments and bug fixes to larrosa@kde.org
    or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain

***************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <signal.h>

#include <tqwidget.h>
#include <tqtextcodec.h>

#include <tdeapplication.h>
#include <tdelocale.h>
#include <tdeio/job.h>
#include <tdecmdlineargs.h>
#include <tdeaboutdata.h>

#include "tdemidframe.h"
#include "tdemid_part.h"
#include "version.h"

int main(int argc, char **argv)
{
    printf("%s Copyright (C) 1997,98,99,2000,01 Antonio Larrosa Jimenez. Malaga (Spain)\n",VERSION_TXT);
    printf("TDEMid comes with ABSOLUTELY NO WARRANTY; for details view file COPYING\n");
    printf("This is free software, and you are welcome to redistribute it\n");
    printf("under certain conditions\n\n");

    TQTextCodec::setCodecForCStrings(TQTextCodec::codecForLocale());
/*
    struct sigaction act;
    act.sa_handler = SIG_DFL;
    sigemptyset(&(act.sa_mask));
    act.sa_flags=0;

    sigaction(SIGINT, &act, NULL);
    sigaction(SIGTERM, &act, NULL);
*/

    TDECmdLineArgs::init(argc, argv, KMidFactory::aboutData() );

    static TDECmdLineOptions options[] =
    {
       { "+file", I18N_NOOP("File to open"), 0 },
       TDECmdLineLastOption
    };
    TDECmdLineArgs::addCmdLineOptions(options);

    TDEApplication app;

    tdemidFrame *tdemidframe=new tdemidFrame("KMid");

    app.setMainWidget ( tdemidframe );

    TQObject::connect(&app,TQT_SIGNAL(shutDown()),tdemidframe,TQT_SLOT(shuttingDown()));

    if (app.isRestored())
        {
        if (tdemidframe->canBeRestored(1)) tdemidframe->restore(1);
        }

    tdemidframe->show();

    //CT    TDEIOJob::initStatic();

/*
    if (app->isRestored())
        {
        RESTORE(tdemidFrame);
        }
       else
        {
        tdemidFrame *tdemidframe=new tdemidFrame("KMid");
        tdemidframe->show();
        };
*/



    return app.exec();
}

==> R14.1.4-core.tar: tdemultimedia-trinity-14.1.4/tdemid/main.cpp <==
/**************************************************************************

    main.cpp  - The main function for KMid
    Copyright (C) 1997,98  Antonio Larrosa Jimenez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Send comments and bug fixes to larrosa@kde.org
    or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain

***************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <signal.h>

#include <tqwidget.h>
#include <tqtextcodec.h>

#include <tdeapplication.h>
#include <tdelocale.h>
#include <tdeio/job.h>
#include <tdecmdlineargs.h>
#include <tdeaboutdata.h>

#include "tdemidframe.h"
#include "tdemid_part.h"
#include "version.h"

int main(int argc, char **argv)
{
    printf("%s Copyright (C) 1997,98,99,2000,01 Antonio Larrosa Jimenez. Malaga (Spain)\n",VERSION_TXT);
    printf("TDEMid comes with ABSOLUTELY NO WARRANTY; for details view file COPYING\n");
    printf("This is free software, and you are welcome to redistribute it\n");
    printf("under certain conditions\n\n");

    TQTextCodec::setCodecForCStrings(TQTextCodec::codecForLocale());
/*
    struct sigaction act;
    act.sa_handler = SIG_DFL;
    sigemptyset(&(act.sa_mask));
    act.sa_flags=0;

    sigaction(SIGINT, &act, NULL);
    sigaction(SIGTERM, &act, NULL);
*/

    TDECmdLineArgs::init(argc, argv, KMidFactory::aboutData() );

    static TDECmdLineOptions options[] =
    {
       { "+file", I18N_NOOP("File to open"), 0 },
       TDECmdLineLastOption
    };
    TDECmdLineArgs::addCmdLineOptions(options);

    TDEApplication app;

    tdemidFrame *tdemidframe=new tdemidFrame("KMid");

    app.setMainWidget ( tdemidframe );

    TQObject::connect(&app,TQ_SIGNAL(shutDown()),tdemidframe,TQ_SLOT(shuttingDown()));

    if (app.isRestored())
        {
        if (tdemidframe->canBeRestored(1)) tdemidframe->restore(1);
        }

    tdemidframe->show();

    //CT    TDEIOJob::initStatic();

/*
    if (app->isRestored())
        {
        RESTORE(tdemidFrame);
        }
       else
        {
        tdemidFrame *tdemidframe=new tdemidFrame("KMid");
        tdemidframe->show();
        };
*/



    return app.exec();
}
